# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class ObjectDetectionBoundingBox(object):
    @poscheck_model
    def __init__(self,
                 top_left_x=None,
                 top_left_y=None,
                 bottom_right_x=None,
                 bottom_right_y=None):
        # type: (float, float, float, float) -> None

        self._top_left_x = None
        self._top_left_y = None
        self._bottom_right_x = None
        self._bottom_right_y = None
        self.discriminator = None

        if top_left_x is not None:
            self.top_left_x = top_left_x
        if top_left_y is not None:
            self.top_left_y = top_left_y
        if bottom_right_x is not None:
            self.bottom_right_x = bottom_right_x
        if bottom_right_y is not None:
            self.bottom_right_y = bottom_right_y

    @property
    def openapi_types(self):
        types = {
            'top_left_x': 'float',
            'top_left_y': 'float',
            'bottom_right_x': 'float',
            'bottom_right_y': 'float'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'top_left_x': 'topLeftX',
            'top_left_y': 'topLeftY',
            'bottom_right_x': 'bottomRightX',
            'bottom_right_y': 'bottomRightY'
        }
        return attributes

    @property
    def top_left_x(self):
        # type: () -> float
        """Gets the top_left_x of this ObjectDetectionBoundingBox.

        Horizontal position of the top left corner, given as a fraction of the frame width

        :return: The top_left_x of this ObjectDetectionBoundingBox.
        :rtype: float
        """
        return self._top_left_x

    @top_left_x.setter
    def top_left_x(self, top_left_x):
        # type: (float) -> None
        """Sets the top_left_x of this ObjectDetectionBoundingBox.

        Horizontal position of the top left corner, given as a fraction of the frame width

        :param top_left_x: The top_left_x of this ObjectDetectionBoundingBox.
        :type: float
        """

        if top_left_x is not None:
            if not isinstance(top_left_x, (float, int)):
                raise TypeError("Invalid type for `top_left_x`, type has to be `float`")

        self._top_left_x = top_left_x

    @property
    def top_left_y(self):
        # type: () -> float
        """Gets the top_left_y of this ObjectDetectionBoundingBox.

        Vertical position of the top left corner, given as a fraction of the frame height

        :return: The top_left_y of this ObjectDetectionBoundingBox.
        :rtype: float
        """
        return self._top_left_y

    @top_left_y.setter
    def top_left_y(self, top_left_y):
        # type: (float) -> None
        """Sets the top_left_y of this ObjectDetectionBoundingBox.

        Vertical position of the top left corner, given as a fraction of the frame height

        :param top_left_y: The top_left_y of this ObjectDetectionBoundingBox.
        :type: float
        """

        if top_left_y is not None:
            if not isinstance(top_left_y, (float, int)):
                raise TypeError("Invalid type for `top_left_y`, type has to be `float`")

        self._top_left_y = top_left_y

    @property
    def bottom_right_x(self):
        # type: () -> float
        """Gets the bottom_right_x of this ObjectDetectionBoundingBox.

        Horizontal position of the bottom right corner, given as a fraction of the frame width

        :return: The bottom_right_x of this ObjectDetectionBoundingBox.
        :rtype: float
        """
        return self._bottom_right_x

    @bottom_right_x.setter
    def bottom_right_x(self, bottom_right_x):
        # type: (float) -> None
        """Sets the bottom_right_x of this ObjectDetectionBoundingBox.

        Horizontal position of the bottom right corner, given as a fraction of the frame width

        :param bottom_right_x: The bottom_right_x of this ObjectDetectionBoundingBox.
        :type: float
        """

        if bottom_right_x is not None:
            if not isinstance(bottom_right_x, (float, int)):
                raise TypeError("Invalid type for `bottom_right_x`, type has to be `float`")

        self._bottom_right_x = bottom_right_x

    @property
    def bottom_right_y(self):
        # type: () -> float
        """Gets the bottom_right_y of this ObjectDetectionBoundingBox.

        Vertical position of the bottom right corner, given as a fraction of the frame height

        :return: The bottom_right_y of this ObjectDetectionBoundingBox.
        :rtype: float
        """
        return self._bottom_right_y

    @bottom_right_y.setter
    def bottom_right_y(self, bottom_right_y):
        # type: (float) -> None
        """Sets the bottom_right_y of this ObjectDetectionBoundingBox.

        Vertical position of the bottom right corner, given as a fraction of the frame height

        :param bottom_right_y: The bottom_right_y of this ObjectDetectionBoundingBox.
        :type: float
        """

        if bottom_right_y is not None:
            if not isinstance(bottom_right_y, (float, int)):
                raise TypeError("Invalid type for `bottom_right_y`, type has to be `float`")

        self._bottom_right_y = bottom_right_y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectDetectionBoundingBox):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.webm.webm_api import WebmApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.webm.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.webm.dash_webm_representation_list_query_params import DashWebmRepresentationListQueryParams



from bitmovin_api_sdk.encoding.statistics.encodings.live.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.encodings.live.daily.encoding_statistics_live_list_by_date_range_query_params import EncodingStatisticsLiveListByDateRangeQueryParams



from bitmovin_api_sdk.encoding.infrastructure.aws.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.aws.regions.aws_account_region_settings_list_query_params import AwsAccountRegionSettingsListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.av1_video_configuration import Av1VideoConfiguration
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.video_configuration import VideoConfiguration
from bitmovin_api_sdk.encoding.configurations.video.av1.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.av1.av1_video_configuration_list_query_params import Av1VideoConfigurationListQueryParams


class Av1Api(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(Av1Api, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, av1_video_configuration, **kwargs):
        # type: (Av1VideoConfiguration, dict) -> Av1VideoConfiguration
        """Create AV1 Codec Configuration

        :param av1_video_configuration: The AV1 Codec Configuration to be created
        :type av1_video_configuration: Av1VideoConfiguration, required
        :return: AV1 video configuration
        :rtype: Av1VideoConfiguration
        """

        return self.api_client.post(
            '/encoding/configurations/video/av1',
            av1_video_configuration,
            type=Av1VideoConfiguration,
            **kwargs
        )

    def delete(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete AV1 Codec Configuration

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: Id of the codec configuration
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/configurations/video/av1/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> Av1VideoConfiguration
        """AV1 Codec Configuration Details

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: AV1 video configuration
        :rtype: Av1VideoConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/video/av1/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=Av1VideoConfiguration,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (Av1VideoConfigurationListQueryParams, dict) -> Av1VideoConfiguration
        """List AV1 Codec Configurations

        :param query_params: Query parameters
        :type query_params: Av1VideoConfigurationListQueryParams
        :return: List of AV1 codec configurations
        :rtype: Av1VideoConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/video/av1',
            query_params=query_params,
            pagination_response=True,
            type=Av1VideoConfiguration,
            **kwargs
        )



from bitmovin_api_sdk.encoding.statistics.daily.daily_api import DailyApi
from bitmovin_api_sdk.encoding.statistics.daily.daily_statistics_list_query_params import DailyStatisticsListQueryParams
from bitmovin_api_sdk.encoding.statistics.daily.daily_statistics_list_by_date_range_query_params import DailyStatisticsListByDateRangeQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AudioMixChannel(object):
    @poscheck_model
    def __init__(self,
                 channel_number=None,
                 source_channels=None):
        # type: (int, list[SourceChannel]) -> None

        self._channel_number = None
        self._source_channels = list()
        self.discriminator = None

        if channel_number is not None:
            self.channel_number = channel_number
        if source_channels is not None:
            self.source_channels = source_channels

    @property
    def openapi_types(self):
        types = {
            'channel_number': 'int',
            'source_channels': 'list[SourceChannel]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'channel_number': 'channelNumber',
            'source_channels': 'sourceChannels'
        }
        return attributes

    @property
    def channel_number(self):
        # type: () -> int
        """Gets the channel_number of this AudioMixChannel.

        Channel number of this mix (starting with 0) (required)

        :return: The channel_number of this AudioMixChannel.
        :rtype: int
        """
        return self._channel_number

    @channel_number.setter
    def channel_number(self, channel_number):
        # type: (int) -> None
        """Sets the channel_number of this AudioMixChannel.

        Channel number of this mix (starting with 0) (required)

        :param channel_number: The channel_number of this AudioMixChannel.
        :type: int
        """

        if channel_number is not None:
            if not isinstance(channel_number, int):
                raise TypeError("Invalid type for `channel_number`, type has to be `int`")

        self._channel_number = channel_number

    @property
    def source_channels(self):
        # type: () -> list[SourceChannel]
        """Gets the source_channels of this AudioMixChannel.

        List of source channels to be mixed (required)

        :return: The source_channels of this AudioMixChannel.
        :rtype: list[SourceChannel]
        """
        return self._source_channels

    @source_channels.setter
    def source_channels(self, source_channels):
        # type: (list) -> None
        """Sets the source_channels of this AudioMixChannel.

        List of source channels to be mixed (required)

        :param source_channels: The source_channels of this AudioMixChannel.
        :type: list[SourceChannel]
        """

        if source_channels is not None:
            if not isinstance(source_channels, list):
                raise TypeError("Invalid type for `source_channels`, type has to be `list[SourceChannel]`")

        self._source_channels = source_channels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AudioMixChannel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
